# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDomainIdentityResult',
    'AwaitableGetDomainIdentityResult',
    'get_domain_identity',
    'get_domain_identity_output',
]

@pulumi.output_type
class GetDomainIdentityResult:
    """
    A collection of values returned by getDomainIdentity.
    """
    def __init__(__self__, arn=None, domain=None, id=None, verification_token=None):
        if arn and not isinstance(arn, str):
            raise TypeError("Expected argument 'arn' to be a str")
        pulumi.set(__self__, "arn", arn)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if verification_token and not isinstance(verification_token, str):
            raise TypeError("Expected argument 'verification_token' to be a str")
        pulumi.set(__self__, "verification_token", verification_token)

    @property
    @pulumi.getter
    def arn(self) -> str:
        """
        ARN of the domain identity.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def domain(self) -> str:
        """
        Name of the domain
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="verificationToken")
    def verification_token(self) -> str:
        """
        Code which when added to the domain as a TXT record will signal to SES that the owner of the domain has authorized SES to act on their behalf.
        """
        return pulumi.get(self, "verification_token")


class AwaitableGetDomainIdentityResult(GetDomainIdentityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDomainIdentityResult(
            arn=self.arn,
            domain=self.domain,
            id=self.id,
            verification_token=self.verification_token)


def get_domain_identity(domain: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDomainIdentityResult:
    """
    Retrieve the SES domain identity

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.ses.get_domain_identity(domain="example.com")
    ```


    :param str domain: Name of the domain
    """
    __args__ = dict()
    __args__['domain'] = domain
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aws:ses/getDomainIdentity:getDomainIdentity', __args__, opts=opts, typ=GetDomainIdentityResult).value

    return AwaitableGetDomainIdentityResult(
        arn=__ret__.arn,
        domain=__ret__.domain,
        id=__ret__.id,
        verification_token=__ret__.verification_token)


@_utilities.lift_output_func(get_domain_identity)
def get_domain_identity_output(domain: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDomainIdentityResult]:
    """
    Retrieve the SES domain identity

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aws as aws

    example = aws.ses.get_domain_identity(domain="example.com")
    ```


    :param str domain: Name of the domain
    """
    ...
